@@ -22,6 +22,10 @@ set -o xtrace
 # Defaults
 # --------
 
+GITREPO["solum-dashboard"]=${SOLUMDASHBOARD_REPO:-${GIT_BASE}/openstack/solum-dashboard.git}
+GITBRANCH["solum-dashboard"]=${SOLUMDASHBOARD_BRANCH:-master}
+GITDIR["solum-dashboard"]=$DEST/solum-dashboard
+
 # Support entry points installation of console scripts
 if [[ -d $SOLUM_DIR/bin ]]; then
     SOLUM_BIN_DIR=$SOLUM_DIR/bin
@@ -84,10 +88,14 @@ function configure_solum() {
 
     # Generate sample config and configure common parameters.
     mkdir -p /tmp/solum
-    pushd $SOLUM_DIR
-        oslo-config-generator --config-file=${SOLUM_DIR}/etc/solum/config-generator.conf --output-file=/tmp/solum/solum.conf.sample
-    popd
-    cp /tmp/solum/solum.conf.sample $SOLUM_CONF_DIR/$SOLUM_CONF_FILE
+
+    # TODO(devkulkarni): Commenting out config generation for now to get around following bug
+    # https://bugs.launchpad.net/solum/+bug/1555788. Instead, including a sample config in the repo
+    #pushd $SOLUM_DIR
+    #    oslo-config-generator --config-file=${SOLUM_DIR}/etc/solum/config-generator.conf --output-file=/tmp/solum/solum.conf.sample
+    #popd
+    #cp /tmp/solum/solum.conf.sample $SOLUM_CONF_DIR/$SOLUM_CONF_FILE
+    cp ${SOLUM_DIR}/devstack/solum.conf.sample $SOLUM_CONF_DIR/$SOLUM_CONF_FILE
 
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE DEFAULT debug $SOLUM_DEBUG
 
@@ -110,6 +118,11 @@ function configure_solum() {
     # configure the database.
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE database connection `database_connection_url solum`
 
+    # configure worker lp operator user/password
+    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE worker lp_operator_user $SOLUM_USER
+    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE worker lp_operator_password $ADMIN_PASSWORD
+    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE worker lp_operator_tenant_name service
+
     # configure the api servers to listen on
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE api host $SOLUM_SERVICE_HOST
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE api port $SOLUM_SERVICE_PORT
@@ -137,21 +150,44 @@ function configure_solum() {
     # configure AllHostsFilter in /etc/nova/nova.conf
     iniset $NOVA_CONF_DIR/$NOVA_CONF_FILE DEFAULT scheduler_default_filters AllHostsFilter
 
-    # Integrate nova-docker with Devstack
+    install_docker
 
-    #git_clone $NOVADOCKER_REPO $NOVADOCKER_PROJ_DIR $NOVADOCKER_BRANCH
-    #cp -R $NOVADOCKER_PROJ_DIR/contrib/devstack/lib/* ${DEVSTACK_DIR}/lib/
-    #cp $NOVADOCKER_PROJ_DIR/contrib/devstack/extras.d/* ${DEVSTACK_DIR}/extras.d/
-
-    #if [ ! -d $NOVA_CONF_DIR/rootwrap.d ] ; then
-    #    mkdir -p $NOVA_CONF_DIR/rootwrap.d
-    #fi
-
-    #cp $NOVADOCKER_PROJ_DIR/$NOVA_CONF_DIR/rootwrap.d/docker.filters $NOVA_CONF_DIR/rootwrap.d/docker.filters
-
-    # configure Virtdriver in /etc/nova/nova.conf
-    # iniset $NOVA_CONF_DIR/$NOVA_CONF_FILE DEFAULT compute_driver novadocker.virt.docker.driver.DockerDriver
+    if [[ $SOLUM_IMAGE_FORMAT == 'docker' ]]; then
+        install_docker_driver
+    elif [[ $SOLUM_IMAGE_FORMAT == 'vm' ]]; then
+        # configure Virtdriver in /etc/nova/nova.conf
+        iniset $NOVA_CONF_DIR/$NOVA_CONF_FILE DEFAULT compute_driver libvirt.LibvirtDriver
+        #solum_install_start_docker_registry
+        #solum_install_core_os
+    else
+        echo "SOLUM_IMAGE_FORMAT docker or vm"
+    fi
+}
+# Install docker driver
+function install_docker_driver() {
+      # Integrate nova-docker with Devstack
+      if [ ! -d /opt/stack/nova-docker ] ; then
+        sudo git clone https://github.com/openstack/nova-docker.git /opt/stack/nova-docker
+      fi
+      cd /opt/stack/nova-docker
+      sudo git checkout 7e55fd551ef4faf3499a8db056efc9535c20e434
+      sudo python setup.py install
+      if [ ! -d $NOVA_CONF_DIR/rootwrap.d ] ; then
+        mkdir -p $NOVA_CONF_DIR/rootwrap.d
+      fi
+      sudo cp /opt/stack/nova-docker/etc/nova/rootwrap.d/docker.filters /etc/nova/rootwrap.d/.
+      # configure Virtdriver in /etc/nova/nova.conf
+      iniset $NOVA_CONF_DIR/$NOVA_CONF_FILE DEFAULT compute_driver novadocker.virt.docker.driver.DockerDriver
+}
 
+# Install docker
+function install_docker() {
+    sudo wget -O docker.deb https://apt.dockerproject.org/repo/pool/main/d/docker-engine/docker-engine_1.7.1-0~trusty_amd64.deb
+    sudo apt-get install -y libapparmor1
+    sudo dpkg -i docker.deb
+    sudo gpasswd -a ${USER} docker
+    sudo usermod -aG docker ${USER}
+    sudo chmod o=rwx /var/run/docker.sock
 }
 
 #register solum user in Keystone
@@ -278,39 +314,17 @@ function install_drone() {
     fi
 }
 
-# install_docker() - Install Docker
-function install_docker() {
-    chmod +x $SOLUM_DIR/contrib/lp-cedarish/docker/get_docker_io.sh
-    sudo $SOLUM_DIR/contrib/lp-cedarish/docker/get_docker_io.sh
-    solum_install_docker_registry
-}
-
-# install_lp-cedarish() - Install tooling to support cedarish LP
-function install_lp-cedarish() {
-    $SOLUM_DIR/contrib/lp-cedarish/docker/prepare
-    install_drone
-}
-
-# install_lp-dockerfile() - Install tooling to support dockerfile LP
-function install_lp-dockerfile() {
-    if [[ $SOLUM_IMAGE_FORMAT == 'docker' ]]; then
-        $SOLUM_DIR/contrib/lp-dockerfile/docker/prepare
-        install_drone
-    else
-        echo does not support VMs
-        exit 1
+function install_solum_dashboard() {
+    git_clone_by_name "solum-dashboard"
+    setup_dev_lib "solum-dashboard"
+    if [ ! -f $HORIZON_DIR/openstack_dashboard/local/enabled/_50_solum.py ] ; then
+      ln -s $DEST/solum-dashboard/_50_solum.py.example $HORIZON_DIR/openstack_dashboard/local/enabled/_50_solum.py
     fi
+    restart_apache_server
 }
 
-# install_lp-chef() - Install tooling to support chef LP
-function install_lp-chef() {
-    if [[ $SOLUM_IMAGE_FORMAT == 'docker' ]]; then
-        $SOLUM_DIR/contrib/lp-chef/docker/prepare
-        install_drone
-    else
-        echo does not support VMs
-        exit 1
-    fi
+function cleanup_solum_dashboard() {
+    rm $HORIZON_DIR/openstack_dashboard/local/enabled/_50_solum.py
 }
 
 # start_solum() - Start running processes, including screen
@@ -319,12 +333,6 @@ function start_solum() {
     screen_it solum-conductor "cd $SOLUM_DIR && $SOLUM_BIN_DIR/solum-conductor --config-file $SOLUM_CONF_DIR/$SOLUM_CONF_FILE"
     screen_it solum-deployer "cd $SOLUM_DIR && $SOLUM_BIN_DIR/solum-deployer --config-file $SOLUM_CONF_DIR/$SOLUM_CONF_FILE"
     screen_it solum-worker "cd $SOLUM_DIR && $SOLUM_BIN_DIR/solum-worker --config-file $SOLUM_CONF_DIR/$SOLUM_CONF_FILE"
-
-    if [[ $SOLUM_IMAGE_FORMAT == 'vm' ]]; then
-        install_docker
-        solum_install_start_docker_registry
-        solum_install_core_os
-    fi
 }
 
 # stop_solum() - Stop running processes
@@ -349,21 +357,20 @@ solum_install_start_docker_registry() {
    sudo apt-get -y install build-essential python-dev libevent-dev python-pip liblzma-dev git libssl-dev python-m2crypto swig
 
  # clone docker registry
-   sudo git clone https://github.com/dotcloud/docker-registry.git /opt/docker-registry
+   if [ ! -d /opt/docker-registry ] ; then
+      sudo git clone https://github.com/dotcloud/docker-registry.git /opt/docker-registry
+   fi
    pushd /opt/docker-registry
-   pip install -r requirements/main.txt
+   sudo  pip install -r requirements/main.txt
    popd
 
- # install docker
-   curl -sSL https://get.docker.com/ubuntu/ | sudo sh
-
  # install docker registry
    pip_command=`which pip`
    pip_build_tmp=$(mktemp --tmpdir -d pip-build.XXXXX)
-   $pip_command install /opt/docker-registry --build=${PIP_BUILD_TMP}
+   sudo $pip_command install /opt/docker-registry --build=${pip_build_tmp}
 
  # initialize config file
-   cp /opt/docker-registry/docker_registry/lib/../../config/config_sample.yml /opt/docker-registry/docker_registry/lib/../../config/config.yml
+   sudo cp /opt/docker-registry/docker_registry/lib/../../config/config_sample.yml /opt/docker-registry/docker_registry/lib/../../config/config.yml
 
  # start docker registry
    gunicorn --access-logfile - --debug -k gevent -b 0.0.0.0:5042 -w 1 docker_registry.wsgi:application &
@@ -386,24 +393,21 @@ solum_install_core_os() {
 #----------------
 
 if is_service_enabled solum-api solum-conductor solum-deployer solum-worker; then
-    echo "Checking for Docker"
-    if [ ! -f /usr/bin/docker ] ; then
-        lsb_release -a | grep -i ubuntu
-        [[ $? != 0 ]] && echo "Currently only Ubuntu supported." && exit 1
-        sudo apt-get -y install docker.io
-    fi
+    #echo "Checking for Docker"
+    #if [ ! -f /usr/bin/docker ] ; then
+    #   echo deb http://get.docker.com/ubuntu docker main | sudo tee /etc/apt/sources.list.d/docker.list
+    #   sudo apt-key adv --keyserver pgp5.ai.mit.edu --recv-keys 36A1D7869245C8950F966E92D8576A8BA88D21E9
+    #   sudo apt-get install -y apt-transport-https
+    #   sudo apt-get update
+    #   sudo apt-get install -y --force-yes lxc-docker-1.7.0
+    #fi
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
         echo_summary "Installing Solum"
         install_solum
         install_solumclient
-        if [[ "$SOLUM_INSTALL_CEDARISH" == "True" ]]; then
-            install_lp-cedarish
-        fi
-        if [[ "$SOLUM_INSTALL_DOCKERFILE" == "True" ]]; then
-            install_lp-dockerfile
-        fi
-        if [[ "$SOLUM_INSTALL_CHEF" == "True" ]]; then
-            install_lp-chef
+        if is_service_enabled horizon; then
+            echo_summary "Installing Solum Dashboard"
+            install_solum_dashboard
         fi
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
         echo_summary "Configuring Solum"
@@ -422,6 +426,10 @@ if is_service_enabled solum-api solum-conductor solum-deployer solum-worker; the
 
     if [[ "$1" == "unstack" ]]; then
         stop_solum
+        if is_service_enabled horizon; then
+            echo_summary "Cleaning Solum Dashboard up"
+            cleanup_solum_dashboard
+        fi
     fi
 fi
 
