@@ -17,12 +17,12 @@ import re
 
 from keystonemiddleware import auth_token
 from oslo_config import cfg
+from oslo_log import log as logging
 from pecan import hooks
 
 from solum.common import context
 from solum.openstack.common.gettextutils import _
 from solum.openstack.common import importutils
-from solum.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
@@ -36,6 +36,11 @@ AUTH_OPTS = [
                 'via keystone. Default value is True.'),
 ]
 
+
+def list_opts():
+    yield None, AUTH_OPTS
+
+
 CONF = cfg.CONF
 CONF.register_opts(AUTH_OPTS)
 
@@ -106,10 +111,12 @@ class AuthInformationHook(hooks.PecanHook):
 
         project_id = headers.get('X-Project-Id')
         user_name = headers.get('X-User-Name', '')
+        tenant_name = headers.get('X-Project')
 
         domain = headers.get('X-Domain-Name')
         project_domain_id = headers.get('X-Project-Domain-Id', '')
         user_domain_id = headers.get('X-User-Domain-Id', '')
+        password = headers.get('X-Password', '')
 
         # Get the auth token
         try:
@@ -136,7 +143,9 @@ class AuthInformationHook(hooks.PecanHook):
                                          project_domain=project_domain_id,
                                          user_name=user_name,
                                          roles=roles,
-                                         auth_url=auth_url)
+                                         auth_url=auth_url,
+                                         password=password,
+                                         tenant_name=tenant_name)
             state.request.security_context = ctx
         else:
             LOG.debug("The provided identity is not confirmed.")
@@ -152,8 +161,8 @@ class AuthInformationHook(hooks.PecanHook):
             # Fallback to deprecated role header:
             roles = req.headers.get('X-Role', '')
             if roles:
-                LOG.warn(_("X-Roles is missing. Using deprecated X-Role "
-                           "header"))
+                LOG.warning(_("X-Roles is missing. Using deprecated X-Role "
+                              "header"))
         return [r.strip() for r in roles.split(',')]
 
 
