@@ -17,6 +17,7 @@ from heatclient import client as heatclient
 from mistralclient.api import client as mistralclient
 from neutronclient.neutron import client as neutronclient
 from oslo_config import cfg
+from oslo_log import log as logging
 from swiftclient import client as swiftclient
 from zaqarclient.queues.v1 import client as zaqarclient
 
@@ -24,7 +25,6 @@ from solum.common import exception
 from solum.common import solum_barbicanclient
 from solum.common import solum_keystoneclient
 from solum.openstack.common.gettextutils import _
-from solum.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
@@ -298,16 +298,21 @@ class OpenStackClients(object):
         return self._mistral
 
     @exception.wrap_keystone_exception
-    def heat(self):
+    def heat(self, username=None, password=None, token=None):
         if self._heat:
             return self._heat
 
+        if token:
+            token_to_use = token
+        else:
+            token_to_use = self.auth_token
+
         endpoint_type = get_client_option('heat', 'endpoint_type')
         args = {
             'auth_url': self.auth_url,
-            'token': self.auth_token,
-            'username': None,
-            'password': None,
+            'token': token_to_use,
+            'username': username,
+            'password': password,
             'ca_file': get_client_option('heat', 'ca_file'),
             'cert_file': get_client_option('heat', 'cert_file'),
             'key_file': get_client_option('heat', 'key_file'),
