@@ -24,6 +24,8 @@ import string
 import subprocess
 
 from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_utils import uuidutils
 import six
 from sqlalchemy import exc as sqla_exc
 
@@ -37,8 +39,6 @@ from solum import objects
 from solum.objects import assembly
 from solum.objects import image
 from solum.openstack.common.gettextutils import _
-from solum.openstack.common import log as logging
-from solum.openstack.common import uuidutils
 import solum.uploaders.local as local_uploader
 import solum.uploaders.swift as swift_uploader
 
@@ -94,6 +94,14 @@ def get_image_by_id(ctxt, image_id):
     return solum.objects.registry.Image.get_by_id(ctxt, image_id)
 
 
+def get_app_by_assem_id(ctxt, assembly_id):
+    assem = get_assembly_by_id(ctxt, assembly_id)
+    if assem:
+        plan = solum.objects.registry.Plan.get_by_id(ctxt, assem.plan_id)
+        app = solum.objects.registry.App.get_by_id(ctxt, plan.uuid)
+        return app
+
+
 def get_parameter_by_assem_id(ctxt, assembly_id):
     assem = get_assembly_by_id(ctxt, assembly_id)
     param_obj = solum.objects.registry.Parameter.get_by_plan_id(ctxt,
@@ -141,12 +149,12 @@ def update_wf_and_app_status(ctxt, assembly_id, status):
             LOG.exception(ex)
 
 
-def update_lp_status(ctxt, image_id, status, external_ref=None,
+def update_lp_status(ctxt, image_id, name, status, external_ref=None,
                      docker_image_name=None):
     if image_id is None:
         return
     LOG.debug('Updating languagepack %s status to %s and external_ref to %s'
-              % (image_id, status, external_ref))
+              % (name, status, external_ref))
     conductor_api.API(context=ctxt).update_image(image_id, status,
                                                  external_ref,
                                                  docker_image_name)
@@ -181,11 +189,17 @@ class Handler(object):
         return du_loc, du_name
 
     @exception.wrap_keystone_exception
-    def _get_environment(self, ctxt, source_uri, assembly_id=None,
+    def _get_environment(self, ctxt, git_info, assembly_id=None,
                          test_cmd=None, run_cmd=None, lp_access=None):
+        source_uri = git_info['source_url']
         # create a minimal environment
         user_env = {}
 
+        private = git_info.get('private', False)
+        ssh_key = git_info.get('private_ssh_key', '')
+        if private and ssh_key:
+            user_env['REPO_DEPLOY_KEYS'] = ssh_key
+
         for var in ['PATH', 'LOGNAME', 'LANG', 'HOME', 'USER', 'TERM']:
             if var in os.environ:
                 user_env[var] = os.environ[var]
@@ -290,8 +304,8 @@ class Handler(object):
                     base_image_id, lp_image_tag]
         elif stage == 'build':
             build_app = os.path.join(build_app_path, 'build-app')
-            return [build_app, source_uri, name, ctxt.tenant, base_image_id,
-                    lp_image_tag]
+            return [build_app, source_uri, commit_sha, name, ctxt.tenant,
+                    base_image_id, lp_image_tag]
 
     def _get_parameter_env(self, ctxt, source_uri, assembly_id, build_id):
         param_env = {}
@@ -386,22 +400,42 @@ class Handler(object):
 
     def _do_deploy(self, ctxt, assembly_id, ports, du_image_loc,
                    du_image_name):
+        app = get_app_by_assem_id(ctxt, assembly_id)
+        LOG.debug("Deploying app %s %s" % (app.name, app.id))
         deployer_api.API(context=ctxt).deploy(assembly_id=assembly_id,
                                               image_loc=du_image_loc,
                                               image_name=du_image_name,
                                               ports=ports)
 
     def _do_scale(self, ctxt, assembly_id):
+        app = get_app_by_assem_id(ctxt, assembly_id)
+        LOG.debug("Scaling app %s %s" % (app.name, app.id))
         deployer_api.API(context=ctxt).scale(assembly_id=assembly_id)
 
     def _do_build(self, ctxt, build_id, git_info, name, base_image_id,
                   source_format, image_format, assembly_id, run_cmd):
         update_assembly_status(ctxt, assembly_id, ASSEMBLY_STATES.BUILDING)
 
+        app = get_app_by_assem_id(ctxt, assembly_id)
+        LOG.debug("Building app %s %s" % (app.name, app.id))
+
         solum.TLS.trace.clear()
         solum.TLS.trace.import_context(ctxt)
 
         source_uri = git_info['source_url']
+        commit_sha = git_info.get('commit_sha', '')
+        private = git_info.get('private', False)
+        ssh_key = git_info.get('private_ssh_key', '')
+        # If the repo is private, make sure private ssh key is provided
+        if private and not ssh_key:
+            LOG.warning("Error building due to missing private ssh key."
+                        " assembly ID: %s" % assembly_id)
+            job_update_notification(ctxt, build_id, IMAGE_STATES.ERROR,
+                                    description='private ssh key missing',
+                                    assembly_id=assembly_id)
+            update_assembly_status(ctxt, assembly_id,
+                                   ASSEMBLY_STATES.ERROR)
+            return
 
         image_tag = ''
         lp_access = ''
@@ -425,14 +459,16 @@ class Handler(object):
 
         build_cmd = self._get_build_command(ctxt, 'build', source_uri,
                                             name, base_image_id,
-                                            source_format, image_format, '',
+                                            source_format, image_format,
+                                            commit_sha,
                                             lp_image_tag=image_tag)
         solum.TLS.trace.support_info(build_cmd=' '.join(build_cmd),
                                      assembly_id=assembly_id)
 
         user_env = {}
         try:
-            user_env = self._get_environment(ctxt, source_uri,
+            user_env = self._get_environment(ctxt,
+                                             git_info,
                                              assembly_id=assembly_id,
                                              run_cmd=run_cmd,
                                              lp_access=lp_access)
@@ -458,7 +494,7 @@ class Handler(object):
         logpath = "%s/%s-%s.log" % (user_env['SOLUM_TASK_DIR'],
                                     'build',
                                     user_env['BUILD_ID'])
-        LOG.debug("Build logs stored at %s" % logpath)
+        LOG.debug("Build logs for app %s stored at %s" % (app.name, logpath))
         out = None
         assem = None
         if assembly_id is not None:
@@ -524,11 +560,13 @@ class Handler(object):
             LOG.debug("Unit test command is None; skipping unittests.")
             return 0
 
+        app = get_app_by_assem_id(ctxt, assembly_id)
+        LOG.debug("Unit testing for app %s %s" % (app.name, app.id))
+
         commit_sha = git_info.get('commit_sha', '')
         status_url = git_info.get('status_url')
         repo_token = git_info.get('repo_token')
 
-        LOG.debug("Running unittests.")
         update_assembly_status(ctxt, assembly_id, ASSEMBLY_STATES.UNIT_TESTING)
 
         image_tag = ''
@@ -557,7 +595,8 @@ class Handler(object):
         solum.TLS.trace.clear()
         solum.TLS.trace.import_context(ctxt)
 
-        user_env = self._get_environment(ctxt, git_url,
+        user_env = self._get_environment(ctxt,
+                                         git_info,
                                          assembly_id=assembly_id,
                                          test_cmd=test_cmd,
                                          lp_access=lp_access)
@@ -640,8 +679,10 @@ class Handler(object):
         return source_private_key
 
     def build_lp(self, ctxt, image_id, git_info, name, source_format,
-                 image_format, artifact_type):
-        update_lp_status(ctxt, image_id, IMAGE_STATES.BUILDING)
+                 image_format, artifact_type, lp_params):
+
+        LOG.debug("Building languagepack %s" % name)
+        update_lp_status(ctxt, image_id, name, IMAGE_STATES.BUILDING)
 
         solum.TLS.trace.clear()
         solum.TLS.trace.import_context(ctxt)
@@ -657,7 +698,7 @@ class Handler(object):
         user_env = {}
         try:
             user_env = self._get_environment(ctxt,
-                                             source_uri,
+                                             git_info,
                                              lp_access=lp_access)
         except exception.SolumException as env_ex:
             LOG.exception(_("Failed to successfully get environment for "
@@ -677,7 +718,8 @@ class Handler(object):
         logpath = "%s/%s-%s.log" % (user_env['SOLUM_TASK_DIR'],
                                     'languagepack',
                                     user_env['BUILD_ID'])
-        LOG.debug("Languagepack logs stored at %s" % logpath)
+        LOG.debug("Languagepack logs for LP %s stored at %s" %
+                  (image_id, logpath))
 
         out = None
         status = IMAGE_STATES.ERROR
@@ -712,7 +754,7 @@ class Handler(object):
 
         img = get_image_by_id(ctxt, image_id)
         img.type = 'languagepack'
-        update_lp_status(ctxt, image_id, status, image_external_ref,
+        update_lp_status(ctxt, image_id, name, status, image_external_ref,
                          docker_image_name)
         upload_task_log(ctxt, logpath, img,
                         img.uuid, 'languagepack')
